@@ -270,6 +270,14 @@ class TestAssertionRewrite:
             assert not 5 % 4
         assert getmsg(f) == "assert not (5 % 4)"
 
+    def test_boolop_percent(self):
+        def f():
+            assert 3 % 2 and False
+        assert getmsg(f) == "assert ((3 % 2) and False)"
+        def f():
+            assert False or 4 % 2
+        assert getmsg(f) == "assert (False or (4 % 2))"
+
     def test_call(self):
         def g(a=42, *args, **kwargs):
             return False
@@ -633,3 +641,27 @@ class TestAssertionRewriteHookDetails(object):
         pyc.write(contents[:strip_bytes], mode='wb')
 
         assert _read_pyc(source, str(pyc)) is None  # no error
+
+    def test_reload_is_same(self, testdir):
+        # A file that will be picked up during collecting.
+        testdir.tmpdir.join("file.py").ensure()
+        testdir.tmpdir.join("pytest.ini").write(py.std.textwrap.dedent("""
+            [pytest]
+            python_files = *.py
+        """))
+
+        testdir.makepyfile(test_fun="""
+            import sys
+            try:
+                from imp import reload
+            except ImportError:
+                pass
+
+            def test_loader():
+                import file
+                assert sys.modules["file"] is reload(file)
+            """)
+        result = testdir.runpytest('-s')
+        result.stdout.fnmatch_lines([
+            "* 1 passed*",
+        ])
